@@ -11,10 +11,11 @@
 
 #include "kleo_export.h"
 
+#include "treewidget.h"
+
 #include <QByteArray>
 #include <QHeaderView>
 #include <QIcon>
-#include <QTreeWidget>
 
 #include <gpgme++/key.h>
 
@@ -76,7 +77,7 @@ private:
     GpgME::Key mKey;
 };
 
-class KLEO_EXPORT KeyListView : public QTreeWidget
+class KLEO_EXPORT KeyListView : public TreeWidget
 {
     Q_OBJECT
     friend class KeyListViewItem;
@@ -94,6 +95,7 @@ public:
         }
 
         virtual QString text(const GpgME::Key &key, int column) const = 0;
+        virtual QString accessibleText(const GpgME::Key &key, int column) const = 0;
         virtual QString toolTip(const GpgME::Key &key, int column) const;
         virtual QIcon icon(const GpgME::Key &, int) const
         {
