@@ -13,15 +13,15 @@
     SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef __KLEO_UI_KEYREQUESTER_H__
-#define __KLEO_UI_KEYREQUESTER_H__
+#pragma once
 
 #include "kleo_export.h"
 
-#include <qgpgme/protocol.h>
+#include <QGpgME/Protocol>
 
-#include <QWidget>
 #include <QLabel>
+#include <QStringList>
+#include <QWidget>
 
 #include <vector>
 
@@ -31,10 +31,8 @@ class Key;
 class KeyListResult;
 }
 
-#include <QStringList>
 class QString;
 class QPushButton;
-class QLabel;
 
 namespace Kleo
 {
@@ -44,11 +42,10 @@ class KLEO_EXPORT KeyRequester : public QWidget
 {
     Q_OBJECT
 public:
-    explicit KeyRequester(unsigned int allowedKeys, bool multipleKeys = false,
-                          QWidget *parent = nullptr);
+    explicit KeyRequester(unsigned int allowedKeys, bool multipleKeys = false, QWidget *parent = nullptr);
     // Constructor for Qt Designer
     explicit KeyRequester(QWidget *parent = nullptr);
-    ~KeyRequester();
+    ~KeyRequester() override;
 
     const GpgME::Key &key() const;
     /** Preferred method to set a key for
@@ -113,6 +110,7 @@ private Q_SLOTS:
 private:
     const QGpgME::Protocol *mOpenPGPBackend = nullptr;
     const QGpgME::Protocol *mSMIMEBackend = nullptr;
+    QLabel *mComplianceIcon = nullptr;
     QLabel *mLabel = nullptr;
     QPushButton *mEraseButton = nullptr;
     QPushButton *mDialogButton = nullptr;
@@ -126,6 +124,7 @@ private:
 private:
     class Private;
     Private *const d;
+
 protected:
     virtual void virtual_hook(int, void *);
 };
@@ -148,13 +147,14 @@ public:
      * Constructor for Qt designer
      */
     explicit EncryptionKeyRequester(QWidget *parent);
-    ~EncryptionKeyRequester();
+    ~EncryptionKeyRequester() override;
 
     void setAllowedKeys(unsigned int proto, bool onlyTrusted = true, bool onlyValid = true);
 
 private:
     class Private;
     Private *const d;
+
 protected:
     void virtual_hook(int, void *) override;
 };
@@ -177,12 +177,13 @@ public:
     explicit SigningKeyRequester(bool multipleKeys = false,
                                  unsigned int proto = AllProtocols,
                                  QWidget *parent = nullptr,
-                                 bool onlyTrusted = true, bool onlyValid = true);
+                                 bool onlyTrusted = true,
+                                 bool onlyValid = true);
     /**
      * Constructor for Qt designer
      */
     explicit SigningKeyRequester(QWidget *parent);
-    ~SigningKeyRequester();
+    ~SigningKeyRequester() override;
 
     /*
      * Those parameters affect the parameters given to the key selection dialog.
@@ -195,10 +196,9 @@ public:
 private:
     class Private;
     Private *const d;
+
 protected:
     void virtual_hook(int, void *) override;
 };
 
 }
-
-#endif // __KLEO_UI_KEYREQUESTER_H__
