@@ -29,7 +29,7 @@ class KLEO_EXPORT TreeWidget : public QTreeWidget
 {
     Q_OBJECT
 public:
-    TreeWidget(QWidget *parent = nullptr);
+    explicit TreeWidget(QWidget *parent = nullptr);
     ~TreeWidget() override;
 
     /**
