@@ -12,6 +12,8 @@
 
 #include "assuan.h"
 
+#include "gnupg.h"
+
 #include <libkleo_debug.h>
 
 #if __has_include(<QGpgME/Debug>)
@@ -66,6 +68,36 @@ bool Kleo::Assuan::agentIsRunning()
     return !err;
 }
 
+static inline bool needsToBePercentEscaped(unsigned char ch)
+{
+    return (ch < ' ') || (ch == '%') || (ch == '+');
+}
+
+QByteArray Kleo::Assuan::escapeAttributeValue(QByteArrayView value)
+{
+    static const char *HexChars = "0123456789ABCDEF";
+    const int numberToPercentEscape = std::ranges::count_if(value, needsToBePercentEscaped);
+    QByteArray result{value.size() + 2 * numberToPercentEscape, Qt::Uninitialized};
+    auto resultIt = result.begin();
+    std::ranges::for_each(value, [&resultIt](unsigned char ch) {
+        if (needsToBePercentEscaped(ch)) {
+            *resultIt = '%';
+            resultIt++;
+            *resultIt = HexChars[ch >> 4];
+            resultIt++;
+            *resultIt = HexChars[ch & 0x0F];
+            resultIt++;
+        } else if (ch == ' ') {
+            *resultIt = '+';
+            resultIt++;
+        } else {
+            *resultIt = ch;
+            resultIt++;
+        }
+    });
+    return result;
+}
+
 std::unique_ptr<GpgME::AssuanTransaction> Kleo::Assuan::sendCommand(std::shared_ptr<GpgME::Context> &context,
                                                                     const std::string &command,
                                                                     std::unique_ptr<GpgME::AssuanTransaction> transaction,
@@ -77,6 +109,9 @@ std::unique_ptr<GpgME::AssuanTransaction> Kleo::Assuan::sendCommand(std::shared_
 
     auto retryDelay = initialRetryDelay;
     while (err.code() == GPG_ERR_ASS_CONNECT_FAILED && connectionAttempts < maxConnectionAttempts) {
+        if (connectionAttempts == 1) {
+            Kleo::launchGpgAgent(Kleo::SkipCheckForRunningAgent);
+        }
         // Esp. on Windows the agent processes may take their time so we try
         // in increasing waits for them to start up
         qCDebug(LIBKLEO_LOG) << "Connecting to the agent failed. Retrying in" << retryDelay.count() << "ms";
